@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
 our $DATE = '2015-12-18'; # DATE
-our $VERSION = '0.71'; # VERSION
+our $VERSION = '0.72'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -168,15 +168,18 @@ sub after_gen_doc {
         my @summary_lines;
         {
             my $summary = $eg->{summary} // "Example #$i";
-            push @summary_lines, ($eg->{summary} . ":", "");
+            push @summary_lines, ("=item * $summary" . ":", "");
         }
-        # XXX example's description
+
+        my @description_lines;
+        push @description_lines, $self->_md2pod($eg->{description}), ""
+            if $eg->{description};
 
         push @eg_lines, (
-            "=item *", "",
             @summary_lines,
             $example_code . (defined($comment) ? " # $comment" : ""), "",
             @result_lines,
+            @description_lines,
         );
     } # for each example
     if (@eg_lines) {
@@ -365,7 +368,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.71 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-12-18.
+This document describes version 0.72 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-12-18.
 
 =head1 SYNOPSIS
 
